@@ -1,6 +1,5 @@
 import json
 import logging
-import re
 import boto3
 import fnmatch
 import os
@@ -87,7 +86,16 @@ class Catalog:
         :param environment: environment
         """
         resource: ResourceItem
-        for resource in data_source.resources:
+        resources = list(
+            filter(
+                lambda r: r.name == resource_name and r.last_processed is not None,
+                data_source.resources,
+            )
+        )
+        assert (
+            len(resources) > 0
+        ), f"No matching resource found for resource name [{resource_name}] that has last_processed"
+        for resource in resources:
             if resource_name == resource.name and resource.last_processed is not None:
                 date_segment: Union[int, List[int]] = (
                     resource.date_segment if resource.date_segment else 0
@@ -108,7 +116,16 @@ class Catalog:
                         date_format
                     )
                 elif isinstance(date_segment, list):
-                    date_format_parts = re.split(r"(%)", date_format)
+                    date_format_parts = []
+                    i: int = -1
+                    for char in date_format:
+                        if char == "%":
+                            i = i + 1
+                            date_format_parts.append("")
+                            date_format_parts[i] = date_format_parts[i] + char
+                        elif i >= 0:
+                            date_format_parts[i] = date_format_parts[i] + char
+
                     for segment, date_format_part in zip(
                         date_segment, date_format_parts
                     ):
