@@ -1,3 +1,4 @@
+import datetime
 import json
 import os.path
 import shutil
@@ -12,13 +13,19 @@ SOURCE_CATALOG = os.path.join(TEST_DIR, "test_catalog")
 SOURCE_DATA = os.path.join(TEST_DIR, "test_data")
 
 
-def setup_module(module: ModuleType) -> None:
+def clean_test_folder() -> None:
+    shutil.rmtree("catalog", ignore_errors=True)
+    shutil.rmtree("data", ignore_errors=True)
     print("Setting up")
     print(" * Copying directory 'test_catalog' to 'catalog' for testing")
     shutil.copytree(src=SOURCE_CATALOG, dst="catalog")
     shutil.copytree(src=SOURCE_DATA, dst="data")
 
 
+def setup_module(module: ModuleType) -> None:
+    clean_test_folder()
+
+
 def teardown_module(module: ModuleType) -> None:
     print("Tearing down")
     print(" * Removing directory 'catalog'")
@@ -27,6 +34,7 @@ def teardown_module(module: ModuleType) -> None:
 
 
 def test_catalog_get_data_source() -> None:
+    clean_test_folder()
     repo = DirectoryRepo(location="")
     catalog = Catalog(repo=repo)
 
@@ -92,6 +100,7 @@ def test_catalog_get_data_source() -> None:
 
 
 def test_catalog_update_data_source_resource() -> None:
+    clean_test_folder()
     repo = DirectoryRepo(location="")
     catalog = Catalog(repo=repo)
     catalog.get_all_data_sources()
@@ -183,6 +192,7 @@ def test_catalog_update_data_source_resource() -> None:
 
 
 def test_catalog_udpate_data_source_resource_with_extension() -> None:
+    clean_test_folder()
     repo = DirectoryRepo(location="")
     catalog = Catalog(repo=repo)
     catalog.get_all_data_sources()
@@ -218,6 +228,7 @@ def test_catalog_udpate_data_source_resource_with_extension() -> None:
 
 
 def test_catalog_update_data_source_resource_returns_none() -> None:
+    clean_test_folder()
     repo = DirectoryRepo(location="")
     catalog = Catalog(repo=repo)
     catalog.get_all_data_sources()
@@ -229,6 +240,7 @@ def test_catalog_update_data_source_resource_returns_none() -> None:
 
 
 def test_catalog_update_resource_last_processed() -> None:
+    clean_test_folder()
     repo = DirectoryRepo(location="")
     catalog = Catalog(repo=repo)
     data_source = catalog.get_data_source(
@@ -255,7 +267,64 @@ def test_catalog_update_resource_last_processed() -> None:
     )
 
 
+def test_catalog_update_resource_last_processed_date_for_single_segment() -> None:
+    clean_test_folder()
+    repo = DirectoryRepo(location="")
+    catalog = Catalog(repo=repo)
+    data_source = catalog.get_data_source(
+        "catalog/raw/thedacare/betteru.json", HelixEnvironment.PRODUCTION
+    )
+    assert data_source is not None
+    catalog.update_resource_last_processed_date_segment(
+        "betteru",
+        datetime.datetime.strptime("2021-11-11", "%Y-%m-%d"),
+        data_source,
+        HelixEnvironment.PRODUCTION,
+    )
+    data_source = catalog.get_data_source(
+        "catalog/raw/thedacare/betteru.json", HelixEnvironment.PRODUCTION
+    )
+    assert data_source is not None
+    people_resource = data_source.resources[0]
+    assert people_resource is not None
+    last_processed = people_resource.last_processed
+    assert last_processed is not None
+    assert (
+        last_processed.get_last_processed(HelixEnvironment.PRODUCTION)
+        == "data/raw/thedacare/betteru/2021-11-11/patient-files/some-patient-file.csv"
+    )
+
+
+def test_catalog_update_resource_last_processed_date_for_multiple_segments() -> None:
+    clean_test_folder()
+    repo = DirectoryRepo(location="")
+    catalog = Catalog(repo=repo)
+    data_source = catalog.get_data_source(
+        "catalog/events/mixpanel/events.json", HelixEnvironment.PRODUCTION
+    )
+    assert data_source is not None
+    catalog.update_resource_last_processed_date_segment(
+        "2095895",
+        datetime.datetime.strptime("2021-11-11", "%Y-%m-%d"),
+        data_source,
+        HelixEnvironment.PRODUCTION,
+    )
+    data_source = catalog.get_data_source(
+        "catalog/events/mixpanel/events.json", HelixEnvironment.PRODUCTION
+    )
+    assert data_source is not None
+    people_resource = data_source.resources[0]
+    assert people_resource is not None
+    last_processed = people_resource.last_processed
+    assert last_processed is not None
+    assert (
+        last_processed.get_last_processed(HelixEnvironment.PRODUCTION)
+        == "data/events/2095895/2021/11/11/full_day/some-patient-file.csv"
+    )
+
+
 def test_catalog_get_resource_unprocessed_directories() -> None:
+    clean_test_folder()
     repo = DirectoryRepo(location="")
     catalog = Catalog(repo=repo)
     data_source = catalog.get_data_source(
@@ -283,6 +352,7 @@ def test_catalog_get_resource_unprocessed_directories() -> None:
 
 
 def test_catalog_get_resource_unprocessed_directories_segments() -> None:
+    clean_test_folder()
     repo = DirectoryRepo(location="")
     catalog = Catalog(repo=repo)
     data_source = catalog.get_data_source(
